@@ -9,10 +9,6 @@
 #define OPENBLAS_NEEDBUNDERSCORE 1
 #define OPENBLAS_NEED2UNDERSCORES 0
 #define OPENBLAS_ARMV7
-#define OPENBLAS_HAVE_VFP
-#define OPENBLAS_HAVE_VFPV3
-#define OPENBLAS_HAVE_NEON
-#define OPENBLAS_HAVE_VFPV4
 #define OPENBLAS_L1_DATA_SIZE 65536
 #define OPENBLAS_L1_DATA_LINESIZE 32
 #define OPENBLAS_L2_SIZE 512488
@@ -20,6 +16,9 @@
 #define OPENBLAS_DTB_DEFAULT_ENTRIES 64
 #define OPENBLAS_DTB_SIZE 4096
 #define OPENBLAS_L2_ASSOCIATIVE 4
+#define OPENBLAS_HAVE_VFPV3
+#define OPENBLAS_HAVE_VFP
+#define OPENBLAS_CORE_ARMV7
 #define OPENBLAS_CHAR_CORENAME "ARMV7"
 #define OPENBLAS_GEMM_MULTITHREAD_THRESHOLD	4
 #define OPENBLAS_VERSION "OpenBLAS 0.3.26"
